@@ -1,23 +1,23 @@
+from .core.make import MakeSummary
+from .group_tree.atom import Atom, Mem, Memnone, Memstr
+from .group_tree.core import make
+from .group_tree.file import File, IFile, VFile
 from .group_tree.groups import (
-    UntypedGroup,
-    StaticGroupBase,
     GroupsGroup,
     RulesGroup,
+    StaticGroupBase,
+    UntypedGroup,
 )
-from .group_tree.core import make
-from .group_tree.atom import Atom, Mem, Memstr, Memnone
-from .group_tree.rule import Rule, SELF
-from .group_tree.file import File, VFile, IFile
+from .group_tree.rule import SELF, Rule
 from .group_tree.tools.graphviz import print_graphviz
 from .group_tree.tools.mermaid import print_mermaid
 from .group_tree.tools.misc import (
-    print_method,
     print_dirtree,
+    print_method,
     stringify_dirtree,
 )
-from .core.make import MakeSummary
 
-VERSION = "0.5.1"  # Automatically set by hatch
+VERSION = "0.5.2"  # Automatically set by hatch
 
 __all__ = [
     "SELF",
