@@ -1,33 +1,38 @@
 from __future__ import annotations
-from abc import ABCMeta, abstractmethod
-import os
+
 import itertools
+import os
+from abc import ABCMeta, abstractmethod
+from pathlib import Path
 from typing import (
     Callable,
     Collection,
+    Dict,
+    Iterator,
+    List,
     Mapping,
     Optional,
+    Sequence,
+    Set,
     Tuple,
     TypeVar,
-    Dict,
     Union,
-    overload,
-    Sequence,
-    List,
-    Set,
     final,
+    overload,
 )
-from typing_extensions import ParamSpec, Concatenate
-from pathlib import Path
 
-from ..raw_rule import Rule as _RawRule, IMemo
-from ..core.make import MakeSummary, make as _make
-from ..core.make_mp import make_mp_spawn
+from typing_extensions import Concatenate, ParamSpec
+
 from ..core.abc import IEvent
+from ..core.make import MakeSummary
+from ..core.make import make as _make
+from ..core.make_mp import make_mp_spawn
 from ..logwriter import IWriter
-from .event_logger import log_make_event, INoArgFunc
+from ..raw_rule import IMemo
+from ..raw_rule import Rule as _RawRule
 from ..utils.strpath import StrOrPath, fspath2str
 from .atom import IAtom
+from .event_logger import INoArgFunc, log_make_event
 
 
 class INode(metaclass=ABCMeta):
@@ -276,6 +281,7 @@ class RuleStore:
         "idx2xpaths",
         "path2file",
         "idx2name",
+        "dirtree",
     )
 
     rules: List[_RawRule[int, INoArgFunc]]
@@ -283,6 +289,7 @@ class RuleStore:
     idx2xpaths: Dict[int, Sequence[str]]
     path2file: Dict[str, IFile]
     idx2name: Dict[int, Tuple[str, ...]]
+    dirtree: DirTree
 
     def __init__(self):
         self.rules = []
@@ -290,6 +297,7 @@ class RuleStore:
         self.idx2xpaths = {}
         self.path2file = {}
         self.idx2name = {}
+        self.dirtree = DirTree()
 
     def add(
         self,
@@ -306,6 +314,8 @@ class RuleStore:
                     f"File {f} is already used as an output of another rule"
                 )
 
+            self.dirtree.assert_no_collision(Path(f).parts, True)
+
         # Check IFile type consistency of xfiles
         for p, f in xp2f.items():
             f_ = self.path2file.get(p)
@@ -347,9 +357,80 @@ class RuleStore:
 
         self.idx2name[id] = name
 
+        for f in yp2f.values():
+            self.dirtree.add(Path(f).parts, True)
+
         return rule
 
 
+class DirTree(Mapping[str, object]):
+    trie: dict[str, DirTree | None]
+
+    def __init__(self) -> None:
+        self.trie = {}
+
+    def __getitem__(self, __key: str) -> DirTree | None:
+        return self.trie[__key]
+
+    def __iter__(self) -> Iterator[str]:
+        return iter(self.trie)
+
+    def __len__(self) -> int:
+        return len(self.trie)
+
+    def assert_no_collision(
+        self, parts: tuple[str, ...], is_file: bool, depth: int = 0
+    ):
+        trie = self.trie
+
+        if len(parts) <= depth:
+            return
+
+        p0 = parts[depth]
+
+        if len(parts) == 1 and is_file:
+            if trie.get(p0) is not None:
+                raise Exception(
+                    f"Directory-vs-File collision was detected. "
+                    f"You tried to register a file {Path(*parts)}, "
+                    f"but it is already registered as a directory."
+                )
+        elif p0 in trie:
+            child = trie[p0]
+
+            if child is None:
+                raise Exception(
+                    f"Directory-vs-File collision was detected. "
+                    f"You tried to register a path {Path(*parts)}, but "
+                    f"{Path(*parts[: depth + 1])} is already registered "
+                    f"as a file. "
+                )
+            else:
+                child.assert_no_collision(parts, is_file, depth + 1)
+
+    def add(self, parts: tuple[str, ...], is_file: bool, depth: int = 0):
+        trie = self.trie
+
+        if len(parts) <= depth:
+            return
+
+        p0 = parts[depth]
+
+        if len(parts) == 1 and is_file:
+            if p0 not in trie:
+                trie[p0] = None
+
+            return
+
+        if p0 in trie:
+            child = trie[p0]
+            assert child is not None
+        else:
+            child = trie[p0] = DirTree()
+
+        child.add(parts, is_file, depth + 1)
+
+
 class GroupTreeInfo:
     __slots__ = (
         "rule_store",
