@@ -1,33 +1,30 @@
 from __future__ import annotations
+
 import inspect
 from typing import (
     Any,
+    Callable,
     Dict,
+    Generic,
     Mapping,
     Optional,
     Tuple,
     Type,
     TypeVar,
-    Generic,
     Union,
     get_origin,
     get_type_hints,
-    Callable,
     overload,
 )
 
-from ..utils.strpath import StrOrPath
 from ..utils.dict_view import DictView
-from .core import IGroup, GroupTreeInfo
-from .rule import Rule
-from .group_mixins.basic import (
-    BasicMixin,
-    BasicInitMixin,
-)
+from ..utils.strpath import StrOrPath
+from .core import GroupTreeInfo, IGroup
+from .group_mixins.basic import BasicInitMixin, BasicMixin
 from .group_mixins.dynamic_container import DynamicRuleContainerMixin
 from .group_mixins.memo import MemoMixin
 from .group_mixins.selector import SelectorMixin
-
+from .rule import Rule
 
 V = TypeVar("V")
 
@@ -159,7 +156,8 @@ class StaticGroupBase(BasicMixin, BasicInitMixin, SelectorMixin, MemoMixin):
 
             if tp == Rule:
                 # Rule
-                r: Rule[str] = Rule.__new__(Rule)
+                r_: Any = Rule.__new__(Rule)
+                r: Rule[str] = r_
                 r.__init_partial__(fqcname, self._info, None, self)
                 setattr(self, child_name, r)
                 self._rules[child_name] = r
